##############################
##  Load in packages and data
##############################

library(tidyr)
library(tidyverse)
library(ggthemes)
library(dplyr)
library(ggpubr)
library(reshape2)
library(FactoMineR)
library(missMDA)
library(corrplot)
library(factoextra)
library(lubridate)
library(socviz)
library(scales)
library(broom)
library(AICcmodavg)
library("readxl")


wb_data_f1 <- read_excel("data/wbR_F1.xlsx")
wb_data_f1

wb_data_f2 <- read_excel("data/wbR_F2.xlsx")
wb_data_f2

lr <- read_excel("data/wb_data_analysis.xlsx")
lr


################################################################################
################################## VIZ #########################################
################################################################################

################################################################################ F1

date<-as.Date(wb_data_f1$DATE)
date

wb_data_f1 <- wb_data_f1 %>% cbind(date)
wb_data_f1$date

wb_data_f1$date[12] #6/16/20
wb_data_f1$date[48] #7/22/20
wb_data_f1$date[54] #7/28/20
wb_data_f1$date[86] #8/29/20
wb_data_f1$date[327] #4/27/21
wb_data_f1$date[334] #5/4/21
wb_data_f1$date[341] #5/11/21
wb_data_f1$date[348] #5/18/21
wb_data_f1$date[354] #5/24/21
wb_data_f1$date[362] #6/1/21
wb_data_f1$date[414] #7/23/21
wb_data_f1$date[422] #7/31/21


wb_data_f1$date[493] #end

max(wb_data_f2$gw1_m, na.rm=TRUE)
#max gw is 2.644 for f1
#max gw is 4.25 for f2

wb_data_f1 <- within(wb_data_f1, DP_m[DP_m<0] <- 0)
wb_data_f1

wb_data_f1$DP_ymin <- "NA"
wb_data_f1[which(wb_data_f1$DP_m!=0),]$DP_ymin <- 5.5-wb_data_f1[which(wb_data_f1$DP_m!=0),]$DP_m


wb_data_f1 <- within(wb_data_f1, gw1_m[gw1_m==0] <- NA)
wb_data_f1 <- within(wb_data_f1, gw2_m[gw2_m==0] <- NA)
wb_data_f1 <- within(wb_data_f1, gw3_m[gw3_m==0] <- NA)

colors <- c("F1_gw1" = "#E69F00", "F1_gw2" = "#009E73", "F1_gw3" = "#56B4E9", "DP" = "black")

v <- ggplot(data = wb_data_f1,
            mapping = aes(x = date))

vf1c <- v + 
  geom_rect(aes(xmin = as.Date(wb_data_f1$date[1]), xmax = as.Date(wb_data_f1$date[493]),
                ymin = 5.5, ymax = 6), fill = "grey", alpha = 0.1) +
  annotate("text", x = as.Date(wb_data_f1$date[246]), y = 5.8,
           label = paste("0.5 m root zone")) +
  annotate("text", x = as.Date(wb_data_f1$date[246]), y = 6.2,
           label = paste("\U2190 Irrigation events \U2192")) +
  geom_vline(xintercept = as.Date(wb_data_f1$date[12]), linetype = 1, colour = "grey") +
  #annotate("text", x = as.Date(wb_data_f1$date[12]), y = 4.7,
  #         label = paste("paste(1)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f1$date[48]), linetype = 1, colour = "grey") +
  #annotate("text", x = as.Date(wb_data_f1$date[48]), y = 4.7,
  #         label = paste("paste(2)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f1$date[54]), linetype = 1, colour = "grey") +
  #annotate("text", x = as.Date(wb_data_f1$date[54]), y = 4.7,
  #         label = paste("paste(3)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f1$date[86]), linetype = 1, colour = "grey") +
  #annotate("text", x = as.Date(wb_data_f1$date[86]), y = 4.7,
  #         label = paste("paste(4)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f1$date[327]), linetype = 1, colour = "grey") +
  #annotate("text", x = as.Date(wb_data_f1$date[327]), y = 4.7,
  #         label = paste("paste(5)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f1$date[334]), linetype = 1, colour = "grey") +
  #annotate("text", x = as.Date(wb_data_f1$date[334]), y = 4.7,
  #         label = paste("paste(6)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f1$date[341]), linetype = 1, colour = "grey") +
  #annotate("text", x = as.Date(wb_data_f1$date[341]), y = 4.7,
  #         label = paste("paste(7)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f1$date[348]), linetype = 1, colour = "grey") +
  #annotate("text", x = as.Date(wb_data_f1$date[348]), y = 4.7,
  #         label = paste("paste(8)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f1$date[354]), linetype = 1, colour = "grey") +
  #annotate("text", x = as.Date(wb_data_f1$date[354]), y = 4.7,
  #         label = paste("paste(9)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f1$date[362]), linetype = 1, colour = "grey") +
  #annotate("text", x = as.Date(wb_data_f1$date[362]), y = 4.7,
  #         label = paste("paste(10)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f1$date[414]), linetype = 1, colour = "grey") +
  #annotate("text", x = as.Date(wb_data_f1$date[414]), y = 4.7,
  #         label = paste("paste(11)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f1$date[422]), linetype = 1, colour = "grey") +
  #annotate("text", x = as.Date(wb_data_f1$date[422]), y = 4.7,
  #         label = paste("paste(12)"), parse = TRUE) +
  geom_linerange(data = subset(wb_data_f1,DP_ymin %nin% "NA"),
                 aes(x = date, ymin = as.numeric(DP_ymin), ymax = 5.5, colour = "DP"), size = 1.5) +
  scale_x_date(date_breaks = "1 month", date_labels = "%b %Y") +
  geom_line(aes(y = gw1_m, color = "F1_gw1"), size = 1) +
  geom_line(aes(y = gw2_m, color = "F1_gw2"), size = 1) +
  geom_line(aes(y = gw3_m, color = "F1_gw3"), size = 1) +
  labs(x = "",
       color = "",
       y = "Groundwater level fluctuation \n& deep percolation (m)",
       subtitle = "(a)") +
  scale_color_manual("", values = colors) +
  theme_bw() +
  theme(panel.grid = element_blank(),
        legend.position = "bottom",
        legend.background = element_blank(),
        #legend.box.background = element_rect(colour = "black"),
        axis.text.x = element_text(size = 10, angle = 45, hjust = 1),
        plot.subtitle = element_text(size = 12, hjust = 0, face = "bold"),
        strip.background = element_rect(color = NA, fill = NA),
        strip.text = element_text(face = "bold.italic", size = 8)) 
vf1c 



################################################################################ F2

date<-as.Date(wb_data_f2$DATE)
date

wb_data_f2 <- wb_data_f2 %>% cbind(date)
wb_data_f2$date

wb_data_f2$date[1] #6/4/20
wb_data_f2$date[4] #6/7/20
wb_data_f2$date[10] #6/13/20
wb_data_f2$date[18] #6/21/20
wb_data_f2$date[19] #6/22/20
wb_data_f2$date[20] #6/23/20
wb_data_f2$date[22] #6/25/20
wb_data_f2$date[25] #6/28/20
wb_data_f2$date[60] #8/2/20
wb_data_f2$date[61] #8/3/20
wb_data_f2$date[67] #8/9/20
wb_data_f2$date[113] #9/24/20
wb_data_f2$date[142] #10/23/20
wb_data_f2$date[317] #4/16/21
wb_data_f2$date[341] #5/10/21
wb_data_f2$date[342] #5/11/21
wb_data_f2$date[343] #5/12/21
wb_data_f2$date[344] #5/13/21
wb_data_f2$date[345] #5/14/21
wb_data_f2$date[349] #5/18/21
wb_data_f2$date[350] #5/19/21
wb_data_f2$date[354] #5/23/21
wb_data_f2$date[355] #5/24/21
wb_data_f2$date[360] #5/29/21
wb_data_f2$date[362] #5/31/21
wb_data_f2$date[367] #6/5/21
wb_data_f2$date[388] #6/26/21
wb_data_f2$date[424] #8/1/21
wb_data_f2$date[441] #8/18/21
wb_data_f2$date[450] #8/27/21
wb_data_f2$date[452] #8/29/21
wb_data_f2$date[462] #9/8/21
wb_data_f2$date[465] #9/11/21

wb_data_f2$date[494] #end

wb_data_f2 <- within(wb_data_f2, DP_m[DP_m<0] <- 0)
wb_data_f2

wb_data_f2$DP_ymin <- "NA"
wb_data_f2[which(wb_data_f2$DP_m!=0),]$DP_ymin <- 5.5-wb_data_f2[which(wb_data_f2$DP_m!=0),]$DP_m


wb_data_f2 <- within(wb_data_f2, gw1_m[gw1_m==0] <- NA)
wb_data_f2 <- within(wb_data_f2, gw2_m[gw2_m==0] <- NA)
wb_data_f2 <- within(wb_data_f2, gw3_m[gw3_m==0] <- NA)

colors <- c("gw1" = "#E69F00", "gw2" = "#009E73", "gw3" = "#56B4E9", "DP" = "black")

v <- ggplot(data = wb_data_f2,
            mapping = aes(x = date))

vf2c <- v +
  geom_rect(aes(xmin = as.Date(wb_data_f2$date[1]), xmax = as.Date(wb_data_f2$date[494]),
                ymin = 5.5, ymax = 6), fill = "grey", alpha = 0.1) +
  annotate("text", x = as.Date(wb_data_f2$date[247]), y = 5.8,
           label = paste("0.5 m root zone")) +
  annotate("text", x = as.Date(wb_data_f2$date[247]), y = 6.2,
           label = paste("\U2190 Irrigation events \U2192")) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[1]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[1]), y = 6.1,
  #         label = paste("paste(1)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[4]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[4]), y = 6.1,
  #         label = paste("paste(2)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[10]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[10]), y = 6.1,
  #         label = paste("paste(3)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[18]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[18]), y = 6.1,
  #         label = paste("paste(4)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[19]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[19]), y = 6.1,
  #         label = paste("paste(5)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[20]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[20]), y = 6.1,
  #         label = paste("paste(6)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[22]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[22]), y = 6.1,
  #         label = paste("paste(7)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[25]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[25]), y = 6.1,
  #         label = paste("paste(8)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[60]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[60]), y = 6.1,
  #         label = paste("paste(9)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[61]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[61]), y = 6.1,
  #         label = paste("paste(10)"), parse = TRUE, hjust = 1.5) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[67]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[67]), y = 6.1,
  #         label = paste("paste(11)"), parse = TRUE, hjust = 1.5) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[113]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[113]), y = 6.1,
  #         label = paste("paste(12)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[142]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[142]), y = 6.1,
  #         label = paste("paste(13)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[317]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[317]), y = 6.1,
  #         label = paste("paste(14)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[341]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[341]), y = 6.1,
  #         label = paste("paste(15)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[342]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[342]), y = 6.1,
  #         label = paste("paste(16)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[343]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[343]), y = 6.1,
  #         label = paste("paste(17)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[344]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[344]), y = 6.1,
  #         label = paste("paste(18)"), parse = TRUE, hjust = 1.5) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[345]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[345]), y = 6.1,
  #         label = paste("paste(19)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[349]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[349]), y = 6.1,
  #         label = paste("paste(20)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[350]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[350]), y = 6.1,
  #         label = paste("paste(21)"), parse = TRUE, hjust = 1.5) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[354]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[354]), y = 6.1,
  #         label = paste("paste(22)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[355]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[355]), y = 6.1,
  #         label = paste("paste(23)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[360]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[360]), y = 6.1,
  #         label = paste("paste(24)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[362]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[362]), y = 6.1,
  #         label = paste("paste(25)"), parse = TRUE, hjust = 1.5) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[367]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[367]), y = 6.1,
  #         label = paste("paste(26)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[388]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[388]), y = 6.1,
  #         label = paste("paste(27)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[424]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[424]), y = 6.1,
  #         label = paste("paste(28)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[441]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[441]), y = 6.1,
  #         label = paste("paste(29)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[450]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[450]), y = 6.1,
  #         label = paste("paste(30)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[452]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[452]), y = 6.1,
  #         label = paste("paste(31)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[462]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[462]), y = 6.1,
  #         label = paste("paste(32)"), parse = TRUE) +
  geom_vline(xintercept = as.Date(wb_data_f2$date[465]), linetype = 1, colour = "grey", show.legend = NA) +
  #annotate("text", x = as.Date(wb_data_f2$date[465]), y = 6.1,
  #         label = paste("paste(33)"), parse = TRUE, size = 2) +
  geom_linerange(data = subset(wb_data_f2,DP_ymin %nin% "NA"),
                 aes(x = date, ymin = as.numeric(DP_ymin), ymax = 5.5, colour = "DP"), size = 1.5) +
  geom_line(aes(y = gw1_m, colour = "gw1"), size = 1) +
  geom_line(aes(y = gw2_m, colour = "gw2"), size = 1) +
  geom_line(aes(y = gw3_m, colour = "gw3"), size = 1) +
  labs(x = "",
       colour = "",
       y = "Groundwater level fluctuation \n& deep percolation (m)",
       subtitle = "(b)") +
  scale_colour_manual(name = "", values = colors) +
  scale_x_date(date_breaks = "1 month", date_labels = "%b %Y") +
  theme_bw() +
  theme(panel.grid = element_blank(),
        legend.position = "bottom",
        legend.background = element_blank(),
        axis.text.x = element_text(size = 10, angle = 45, hjust = 1),
        plot.subtitle = element_text(size = 12, hjust = 0, face = "bold"),
        strip.background = element_rect(color = NA, fill = NA),
        strip.text = element_text(face = "bold.italic", size = 8)) 
vf2c  


comp.wb <- ggarrange(vf1c, vf2c, nrow = 2, align = "v", heights = c(0.85,1))
comp.wb
ggsave("figures/comp.wb.png", plot = comp.wb, height = 7, width = 6.5, units = "in")



################################################################################
############################### STATS ##########################################
############################# ONLY 2021#########################################
################################################################################

lr <- lr %>% mutate(twaminussm = twa_mm - sm_mm)

f1.lr <- lr[which(lr$field=='1'),]
f1.lr
f1.20.lr <- lr[which(lr$field=='1' & lr$year=='2020'),]
f1.20.lr
f1.21.lr <- lr[which(lr$field=='1' & lr$year=='2021'),]
f1.21.lr
f2.lr <- lr[which(lr$field=='2'),]
f2.lr
f2.20.lr <- lr[which(lr$field=='2' & lr$year=='2020'),]
f2.20.lr
f2.21.lr <- lr[which(lr$field=='2' & lr$year=='2021'),]
f2.21.lr
lr.21 <- lr[which(lr$year=='2021'),]

#### linear regression parameters for indiv fields
# F1
modf1.1 <- lm(dp_mm ~ twa_mm, data=f1.21.lr)
summary(modf1.1)
modf1.2 <- lm(dp_mm ~ twaminussm, data=f1.21.lr)
summary(modf1.2)
modf1.3 <- lm(dp_mm ~ duration_hr, data=f1.21.lr)
summary(modf1.3)
modf1.4 <- lm(dp_mm ~ wlr_gw1_mm, data=f1.21.lr)
summary(modf1.4)
modf1.5 <- lm(dp_mm ~ wlr_gw2_mm, data=f1.21.lr)
summary(modf1.5)
modf1.6 <- lm(dp_mm ~ wlr_gw3_mm, data=f1.21.lr)
summary(modf1.6)
modf1.7 <- lm(twa_mm ~ wlr_gw1_mm, data=f1.21.lr)
summary(modf1.7)
modf1.9 <- lm(twa_mm ~ wlr_gw2_mm, data=f1.21.lr)
summary(modf1.9)
modf1.11 <- lm(twa_mm ~ wlr_gw3_mm, data=f1.21.lr)
summary(modf1.11)

#F2
modf2.1 <- lm(dp_mm ~ twa_mm, data=f2.21.lr)
summary(modf2.1)
modf2.2 <- lm(dp_mm ~ twaminussm, data=f2.21.lr)
summary(modf2.2)
modf2.3 <- lm(dp_mm ~ duration_hr, data=f2.21.lr)
summary(modf2.3)
modf2.4 <- lm(dp_mm ~ wlr_gw1_mm, data=f2.21.lr)
summary(modf2.4)
modf2.5 <- lm(dp_mm ~ wlr_gw2_mm, data=f2.21.lr)
summary(modf2.5)
modf2.6 <- lm(dp_mm ~ wlr_gw3_mm, data=f2.21.lr)
summary(modf2.6)
modf2.7 <- lm(twa_mm ~ wlr_gw1_mm, data=f2.21.lr)
summary(modf2.7)
modf2.9 <- lm(twa_mm ~ wlr_gw2_mm, data=f2.21.lr)
summary(modf2.9)
modf2.11 <- lm(twa_mm ~ wlr_gw3_mm, data=f2.21.lr)
summary(modf2.11)


#### ANOVA for differences between fields
mod1 <- aov(dp_mm ~ field, data = lr.21)
summary(mod1)
LM <- lm(dp_mm ~ field, data = lr.21)
anova(LM)
summary(LM)

mod1 <- aov(twa_mm ~ field, data = lr.21)
summary(mod1)
LM <- lm(twa_mm ~ field, data = lr.21)
anova(LM)
summary(LM)

mod1 <- aov(twaminussm ~ field, data = lr.21)
summary(mod1)
LM <- lm(twaminussm ~ field, data = lr.21)
anova(LM)
summary(LM)

mod1 <- aov(duration_hr ~ field, data = lr.21)
summary(mod1)
LM <- lm(duration_hr ~ field, data = lr.21)
anova(LM)
summary(LM)

mod1 <- aov(irr_event_per_yr ~ field, data = lr.21)
summary(mod1)
LM <- lm(irr_event_per_yr ~ field, data = lr.21)
anova(LM)
summary(LM)













